@@ -532,10 +532,6 @@ ZESW(xc_cest_t *, void) xc_install_class(char *filename, xc_cest_t *cest, int op
 #ifdef ZEND_ENGINE_2_1
 static zend_bool xc_auto_global_callback(char *name, uint name_len TSRMLS_DC) /* {{{ */
 {
-	zend_auto_global *auto_global;
-	if (zend_u_hash_find(CG(auto_globals), UG(unicode) ? IS_UNICODE : IS_STRING, ZSTR(name), name_len + 1, (void **) &auto_global) == FAILURE) {
-		return 1;
-	}
 	return 0;
 }
 /* }}} */
@@ -839,3 +835,43 @@ int xc_trace(const char *fmt, ...) /* {{{ */
 	return ret;
 }
 /* }}} */
+
+#ifndef ZEND_ENGINE_2_3
+size_t zend_dirname(char *path, size_t len) /* {{{ */
+{
+	php_dirname(path, len);
+	return strlen(path);
+}
+/* }}} */
+
+long zend_atol(const char *str, int str_len) /* {{{ */
+{
+	long retval;
+
+	if (!str_len) {
+		str_len = strlen(str);
+	}
+
+	retval = strtol(str, NULL, 0);
+	if (str_len > 0) {
+		switch (str[str_len - 1]) {
+		case 'g':
+		case 'G':
+			retval *= 1024;
+			/* break intentionally missing */
+		case 'm':
+		case 'M':
+			retval *= 1024;
+			/* break intentionally missing */
+		case 'k':
+		case 'K':
+			retval *= 1024;
+			break;
+		}
+	}
+
+	return retval;
+}
+/* }}} */
+
+#endif
